<?php
/**
 * Template Tags
 *
 * Custom template tags e.g. Post nav, Posted on
 *
 * @package      responsive_mobile
 * @license      license.txt
 * @copyright    2014 CyberChimps Inc
 * @since        0.0.1
 *
 * Please do not edit this file. This file is part of the responsive_mobile Framework and all modifications
 * should be made in a child theme.
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( !function_exists( 'responsive_mobile_paging_nav' ) ) {
	/**
	 * Display navigation to next/previous set of posts when applicable.
	 *
	 * @return void
	 */
	function responsive_mobile_paging_nav() {
		// Don't print empty markup if there's only one page.
		if ( $GLOBALS['wp_query']->max_num_pages < 2 ) {
			return;
		}
		?>
		<nav class="navigation paging-navigation" role="navigation">
			<h1 class="screen-reader-text"><?php _e( 'Posts navigation', 'responsive-mobile' ); ?></h1>

			<div class="nav-links">

				<?php if ( get_next_posts_link() ) : ?>
					<div class="nav-previous"><?php next_posts_link( __( '<span class="meta-nav">&larr;</span> Older posts', 'responsive-mobile' ) ); ?></div>
				<?php endif; ?>

				<?php if ( get_previous_posts_link() ) : ?>
					<div class="nav-next"><?php previous_posts_link( __( 'Newer posts <span class="meta-nav">&rarr;</span>', 'responsive-mobile' ) ); ?></div>
				<?php endif; ?>

			</div>
			<!-- .nav-links -->
		</nav><!-- .navigation -->
	<?php
	}
}

if ( !function_exists( 'responsive_mobile_post_nav' ) ) {
	/**
	 * Display navigation to next/previous post when applicable.
	 *
	 * @return void
	 */
	function responsive_mobile_post_nav() {
		// Don't print empty markup if there's nowhere to navigate.
		$previous = ( is_attachment() ) ? get_post( get_post()->post_parent ) : get_adjacent_post( false, '', true );
		$next     = get_adjacent_post( false, '', false );

		if ( !$next && !$previous ) {
			return;
		}
		?>
		<nav class="navigation post-navigation" role="navigation">
			<h1 class="screen-reader-text"><?php _e( 'Post navigation', 'responsive-mobile' ); ?></h1>

			<div class="nav-links">

				<div class="nav-previous"><?php previous_post_link( '%link', _x( '<span class="meta-nav">&larr;</span> %title', 'Previous post link', 'responsive-mobile' ) ); ?></div>
				<div class="nav-next"><?php next_post_link( '%link', _x( '%title <span class="meta-nav">&rarr;</span>', 'Next post link', 'responsive-mobile' ) ); ?></div>

			</div>
			<!-- .nav-links -->
		</nav><!-- .navigation -->
	<?php
	}
}

if ( !function_exists( 'responsive_mobile_post_thumbnail' ) ) {
	/**
	 * Creates the post thumbnail used throughout the templates
	 *
	 * @param string $size
	 * @param null $attr
	 */
	function responsive_mobile_post_thumbnail( $size = 'post-thumbnail', $attr = null ) {
		$size = apply_filters( 'responsive_mobile_filter_the_post_thumbnail_size', $size );
		$attr = apply_filters( 'responsive_mobile_filter_the_post_thumbnail_attr', $attr );
		?>
		<a href="<?php the_permalink(); ?>" title="<?php the_title_attribute(); ?>">
			<?php the_post_thumbnail( $size, $attr ); ?>
		</a>
	<?php
	}
}

/**
 * This function prints post meta data.
 *
 * Ulrich Pogson Contribution
 *
 */
if ( !function_exists( 'responsive_mobile_post_meta_data' ) ) {

	function responsive_mobile_post_meta_data() {
	
		// Apply filter to get by_line_date option working.
		$by_line_date = apply_filters( 'responsive_mobile_by_line_date', '1' );
		if( $by_line_date ) {
			printf(
				/* Translators: (Posted on )(Date) */
				__( '%1$s %2$s', 'responsive-mobile' ),
				'<span class="meta-prep meta-prep-author posted">' . __( 'Posted on', 'responsive-mobile' ) . ' </span>',
				sprintf(
					'<a href="%1$s" title="%2$s" rel="bookmark"><time class="timestamp updated" itemprop="datePublished" datetime="%3$s">%4$s</time></a>',
					esc_url( get_permalink() ),
					esc_attr( get_the_time() ),
					esc_html( get_the_date('c')),
					esc_html( get_the_date() )
				)
			);
		}
		
		// Apply filter to get by_line_author option working.
		$by_line_author = apply_filters( 'responsive_mobile_by_line_author', '1' );
		if( $by_line_author ) {
			printf(
				/* Translators: ( by )(Author) */
				__( '%1$s %2$s', 'responsive-mobile' ),
				'<span class="byline"> ' . __( 'by', 'responsive-mobile' ) . ' </span>',
				sprintf(
					'<span class="author vcard" itemprop="author" itemscope="itemscope" itemtype="http://schema.org/Person"><a class="url fn n" href="%1$s" title="%2$s" itemprop="url" rel="author"><span itemprop="name">%3$s</span></a></span>',
					get_author_posts_url( get_the_author_meta( 'ID' ) ),
					sprintf( esc_attr__( 'View all posts by %s', 'responsive-mobile' ), get_the_author() ),
					esc_attr( get_the_author() )
				)
			);
		}
	}
}

if ( !function_exists( 'responsive_mobile_posted_on' ) ) {
	/**
	 * Prints HTML with meta information for the current post-date/time and author.
	 */
	function responsive_mobile_posted_on() {
		$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time>';
		if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
			$time_string .= '<time class="updated" datetime="%3$s">%4$s</time>';
		}

		$time_string = sprintf( $time_string,
								esc_attr( get_the_date( 'c' ) ),
								esc_html( get_the_date() ),
								esc_attr( get_the_modified_date( 'c' ) ),
								esc_html( get_the_modified_date() )
		);

		printf( __( '<span class="posted-on">Posted on %1$s</span><span class="byline"> by %2$s</span>', 'responsive-mobile' ),
				sprintf( '<a href="%1$s" rel="bookmark">%2$s</a>',
						 esc_url( get_permalink() ),
						 $time_string
				),
				sprintf( '<span class="author vcard"><a class="url fn n" href="%1$s">%2$s</a></span>',
						 esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),
						 esc_html( get_the_author() )
				)
		);
	}
}

/**
 * Returns true if a blog has more than 1 category.
 */
function responsive_mobile_categorized_blog() {
	if ( false === ( $all_the_cool_cats = get_transient( 'all_the_cool_cats' ) ) ) {
		// Create an array of all the categories that are attached to posts.
		$all_the_cool_cats = get_categories( array( 'hide_empty' => 1 ) );

		// Count the number of categories that are attached to the posts.
		$all_the_cool_cats = count( $all_the_cool_cats );

		set_transient( 'all_the_cool_cats', $all_the_cool_cats );
	}

	if ( '1' != $all_the_cool_cats ) {
		// This blog has more than 1 category so responsive_mobile_categorized_blog should return true.
		return true;
	} else {
		// This blog has only 1 category so responsive_mobile_categorized_blog should return false.
		return false;
	}
}

/**
 * Flush out the transients used in responsive_mobile_categorized_blog.
 */
function responsive_mobile_category_transient_flusher() {
	// Like, beat it. Dig?
	delete_transient( 'all_the_cool_cats' );
}

add_action( 'edit_category', 'responsive_mobile_category_transient_flusher' );
add_action( 'save_post', 'responsive_mobile_category_transient_flusher' );

if ( !function_exists( 'responsive_mobile_archive_title' ) ) {
	/**
	 * Prints respective title for the archive page.
	 */
	function responsive_mobile_archive_title( $display = true ) {
		if ( is_category() ) {
			$archive_title = single_cat_title( "", false );

		} elseif ( is_tag() ) {
			$archive_title = single_tag_title( "", false );

		} elseif ( is_author() ) {
			$archive_title = sprintf( __( 'Author: %s', 'responsive-mobile' ), '<span class="vcard">' . get_the_author() . '</span>' );

		} elseif ( is_day() ) {
			$archive_title = sprintf( __( 'Daily Archives: %s', 'responsive-mobile' ), '<span>' . get_the_date() . '</span>' );

		} elseif ( is_month() ) {
			$archive_title = sprintf( __( 'Monthly Archives: %s', 'responsive-mobile' ), '<span>' . get_the_date( _x( 'F Y', 'monthly archives date format', 'responsive-mobile' ) ) . '</span>' );

		} elseif ( is_year() ) {
			$archive_title = sprintf( __( 'Yearly Archives: %s', 'responsive-mobile' ), '<span>' . get_the_date( _x( 'Y', 'yearly archives date format', 'responsive-mobile' ) ) . '</span>' );

		} elseif ( is_tax( 'post_format', 'post-format-aside' ) ) {
			$archive_title = __( 'Asides', 'responsive-mobile' );

		} elseif ( is_tax( 'post_format', 'post-format-gallery' ) ) {
			$archive_title = __( 'Galleries', 'responsive-mobile' );

		} elseif ( is_tax( 'post_format', 'post-format-image' ) ) {
			$archive_title = __( 'Images', 'responsive-mobile' );

		} elseif ( is_tax( 'post_format', 'post-format-video' ) ) {
			$archive_title = __( 'Videos', 'responsive-mobile' );

		} elseif ( is_tax( 'post_format', 'post-format-quote' ) ) {
			$archive_title = __( 'Quotes', 'responsive-mobile' );

		} elseif ( is_tax( 'post_format', 'post-format-link' ) ) {
			$archive_title = __( 'Links', 'responsive-mobile' );

		} elseif ( is_tax( 'post_format', 'post-format-status' ) ) {
			$archive_title = __( 'Statuses', 'responsive-mobile' );

		} elseif ( is_tax( 'post_format', 'post-format-audio' ) ) {
			$archive_title = __( 'Audios', 'responsive-mobile' );

		} elseif ( is_tax( 'post_format', 'post-format-chat' ) ) {
			$archive_title = __( 'Chats', 'responsive-mobile' );

		} else {
			$archive_title = __( 'Archives', 'responsive-mobile' );

		}

		if ( $display ) {
			echo $archive_title;
		} else {
			return $archive_title;
		}

	}
}

/**
 * Mobile menu title
 */
function responsive_mobile_menu_title( $display = true ) {

	$page_title = __( 'Menu', 'responsive-mobile' );

	$page_title = apply_filters( 'responsive_mobile_menu_title', $page_title );

	if ( $display ) {
		echo $page_title;
	} else {
		return $page_title;
	}

}
